#!/usr/bin/sh

#ident	"%W%"

#
# The source files here are entirely from:
#
#	gimp-print-4.2.5 distribution from http://gimp-print.sourceforge.net/
#
# except for the following files:
#
# - gimp-print-4.2.5.sh			(this file)
# - gimp-print-4.2.5.depend		(depend file)
# - gimp-print-4.2.5-unixware.patch	(patch file)
#

set -x
set -e

#
# We need BSD-compatible install command.
#
INSTALL="/usr/ucb/install"
if [ ! -x ${INSTALL} ]
then
	echo "ERROR: ${INSTALL} not found." >&2
	exit 1
fi
export INSTALL

#
# We need cups-config command built by cups-1.1.19.
#
CUPS_CONFIG="`pwd`/../cups-1.1.19/cups-config"
if [ ! -x ${CUPS_CONFIG} ]
then
	echo "ERROR: ${CUPS_CONFIG} not found." >&2
	exit 1
fi
export CUPS_CONFIG

#
# We need ijs-config command built by espgs-7.05.6.
#
IJS_CONFIG="`pwd`/../espgs-7.05.6/ijs/ijs-config"
if [ ! -x ${IJS_CONFIG} ]
then
	echo "ERROR: ${IJS_CONFIG} not found." >&2
	exit 1
fi
export IJS_CONFIG

#
# Apply patches.
#
for patch in gimp-print-4.2.5-unixware
do
	[ -f .${patch}.applied ] || {
		/bin/patch -c -p0 -i ${patch}.patch
		/bin/date > .${patch}.applied
	}
done

#
# configure script understands AR_FLAGS and not ARFLAGS.
#
AR_FLAGS="${ARFLAGS}"
export AR_FLAGS

#
# Disable adding -lc while linking.
# (Can't find a better way to stop ./configure from setting it to yes.)
#
lt_cv_archive_cmds_need_lc=no
export lt_cv_archive_cmds_need_lc

#
# Configre
#
# --cache-file=/dev/null	(always start fresh)
#
# --with-cups			(build drivers and PPD files for cups)
#
# --with-ijs			(build ijs driver for foomatic)
# --without-foomatic		(do not build foomatic PPDs, they come with
# 				 foomatic distribution)
#
# The following are enabled by default
#
# --with-user-guide
# --with-samples
# --with-escputil
# --enable-libgimpprint
# --enable-shared
# --enable-static
# --enable-fast-install
#
# The following are disbled by default
#
# --enable-cups-level3-ps
# --with-ghost
# --enable-debug
# --with-testpattern
# --enable-test
# --enable-user-install
# --with-gnu-ld
#
./configure \
	--cache-file=/dev/null \
	--prefix=/usr \
	--sysconfdir=/etc \
	--localstatedir=/var \
	--without-gimp \
	--with-cups \
	--without-translated-ppds \
	--with-ijs \
	--without-foomatic \
	--without-readline \
	--disable-nls

#
# We need GNU make
#
MAKE=/usr/add-on/public/bin/gmake
export MAKE

#
# HACK: fz528972:1
# Touch src/printdef/printdefl.c otherwise make will attempt to regenerate
# it from src/printdef/printdefl.l using lex -i and fail since our lex does
# not support -i option.
#
/bin/touch src/printdef/printdefl.c

#
# Make and install in ${ROOT}/${MACH}
#
${MAKE} \
	DESTDIR=${ROOT}/${MACH} \
	install
